*+--------------------------------------------------------------------
*+
*+ Source Module => c:\hmg.3.4.4\0\FORUMHMG\COLOR.PRG
*+
*+    Copyright(C) 1983-2022 by Auge & Ohr
*+
*+    Functions: Procedure Setup_Color()
*+               Static Procedure DoColorInit()
*+               Static Procedure COLOR_STORE()
*+               Static Procedure COLOR_REPLACE()
*+               Static Procedure DoSaveandExit()
*+               Static Procedure ColorPicker()
*+               Function NumColor2RGB()
*+               Function SysColor2Num()
*+
*+    Reformatted by Click! 2.05.40 on Oct-6-2022 at  3:32 am
*+
*+--------------------------------------------------------------------

#INCLUDE 'HMG.CH'
#INCLUDE 'common.CH'
#INCLUDE "COLOR.CH"

MEMVAR _HMG_SYSDATA
MEMVAR BGcolor, BFcolor, FGfont, BGfont

*+--------------------------------------------------------------------
*+
*+    Procedure Setup_Color()
*+
*+    Called from ( forumhmg.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
PROCEDURE Setup_Color()

   SELECT 5
   // USE COLOR.DBF VIA "DBFCDX" // EXCLUSIVE
   IF Net_Use( "COLOR.DBF", .T. )
   ELSE
      MsgInfo( "Error open DBF", "COLOR.DBF" )
      RETURN
   ENDIF

   DEFINE WINDOW COLOR_SETUP AT 0, 0 ;
         WIDTH 300 + 30 ;
         HEIGHT 100 ;
         TITLE "Color" ;
         ICON "AUGEOHR" ;
         ON INIT DoColorInit( ThisWindow.Name ) ;
         ON SIZE LayoutAdjust( ThisWindow.Name, 330, 100 ) ;
         ON MAXIMIZE LayoutAdjust( ThisWindow.Name, 330, 100 ) ;
         NOSIZE ;
         NOMAXIMIZE ;
         NOMINIMIZE ;
         BACKCOLOR BGfont

      DEFINE BUTTON BUTTON_001
         ROW 10
         COL 10
         WIDTH 80
         HEIGHT 24
         ACTION ColorPicker( 1 )
         CAPTION "&Background"
         FONTNAME "Arial"
         FONTSIZE 11
         VISIBLE .T.
      END BUTTON

      DEFINE BUTTON BUTTON_002
         ROW 40
         COL 10
         WIDTH 80
         HEIGHT 24
         ACTION ColorPicker( 2 )
         CAPTION "&Foreground"
         FONTNAME "Arial"
         FONTSIZE 11
         VISIBLE .T.
      END BUTTON

      DEFINE TEXTBOX Text_BACKGROUND
         ROW 10
         COL 100
         WIDTH 90
         HEIGHT 24
         FONTNAME "Arial"
         FONTSIZE 11
         TABSTOP .T.
         VISIBLE .T.
         DISABLEDBACKCOLOR Nil
         DISABLEDFONTCOLOR Nil
         BACKCOLOR BGfont
         FONTCOLOR FGfont
         MAXLENGTH 9
         DATATYPE NUMERIC
         VALUE 0
      END TEXTBOX

      DEFINE TEXTBOX Text_FOREGRAUND
         ROW 40
         COL 100
         WIDTH 90
         HEIGHT 24
         FONTNAME "Arial"
         FONTSIZE 11
         TABSTOP .T.
         VISIBLE .T.
         DISABLEDBACKCOLOR Nil
         DISABLEDFONTCOLOR Nil
         BACKCOLOR BGfont
         FONTCOLOR FGfont
         MAXLENGTH 9
         DATATYPE NUMERIC
         VALUE 0
      END TEXTBOX

      DEFINE LABEL Label_001
         ROW 10
         COL 200
         WIDTH 20
         HEIGHT 24
         VALUE ""
         FONTNAME "Arial"
         FONTSIZE 11
         VISIBLE .T.
         BACKCOLOR BGfont
         FONTCOLOR FGfont
         ACTION ColorPicker( 1 )
         TOOLTIP "press me"
      END LABEL

      DEFINE LABEL Label_002
         ROW 40
         COL 200
         WIDTH 20
         HEIGHT 24
         VALUE ""
         FONTNAME "Arial"
         FONTSIZE 11
         VISIBLE .T.
         BACKCOLOR BGfont
         FONTCOLOR FGfont
         ACTION ColorPicker( 2 )
         TOOLTIP "press me"
      END LABEL

      DEFINE BUTTON BUTTON_OK
         ROW 10
         COL 210 + 30
         WIDTH 64
         HEIGHT 56
         ACTION DoSaveandExit()
         CAPTION "&Save"
         FONTNAME "Arial"
         FONTSIZE 11
         VISIBLE .T.
      END BUTTON

   END WINDOW

   ON KEY ESCAPE OF COLOR_SETUP ACTION COLOR_SETUP.release

   CENTER WINDOW COLOR_SETUP
   Activate Window COLOR_SETUP

   SELECT 5
   CLOSE

   SELECT 1

RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure DoColorInit()
*+
*+    Called from ( color.prg )   1 - procedure setup_color()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE DoColorInit( cForm )

LOCAL nWIDTH  := GetProperty( cForm, "WIDTH" )
LOCAL nHEIGHT := GetProperty( cForm, "HEIGHT" )
LOCAL aZoom   := GetZoomFactor()

   GetLayout( cForm )

   // new Size -> resize Layout
   SetProperty( cForm, "WIDTH", 330 * aZoom[ 1 ] )
   SetProperty( cForm, "HEIGHT", 100 * aZoom[ 2 ] )
   LayoutAdjust( cForm, 330, 100 )

   CENTER WINDOW &cForm

   COLOR_STORE()
   COLOR_SETUP.Label_002.BackColor := FGfont
   COLOR_SETUP.Label_001.BackColor := BGfont

RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure COLOR_STORE()
*+
*+    Called from ( color.prg )   1 - static procedure docolorinit()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE COLOR_STORE()

   COLOR_SETUP.Text_BACKGROUND.Value := FIELD->BACKGROUND
   COLOR_SETUP.Text_FOREGRAUND.Value := FIELD->FOREGRAUND
RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure COLOR_REPLACE()
*+
*+    Called from ( color.prg )   1 - static procedure dosaveandexit()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE COLOR_REPLACE()

LOCAL nRecord := RECNO()

   IF Net_Lock( nRecord )
      REPLACE FIELD->BACKGROUND WITH COLOR_SETUP.Text_BACKGROUND.Value
      REPLACE FIELD->FOREGRAUND WITH COLOR_SETUP.Text_FOREGRAUND.Value
      DBRUNLOCK( nRecord )

      BGfont := NumColor2RGB( COLOR_SETUP.Text_BACKGROUND.Value )
      FGfont := NumColor2RGB( COLOR_SETUP.Text_FOREGRAUND.Value )
   ENDIF
RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure DoSaveandExit()
*+
*+    Called from ( color.prg )   1 - procedure setup_color()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE DoSaveandExit()

   COLOR_REPLACE()
   COLOR_SETUP.release
RETURN

*+--------------------------------------------------------------------
*+
*+    Static Procedure ColorPicker()
*+
*+    Called from ( color.prg )   4 - procedure setup_color()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE ColorPicker( nNo )

LOCAL aColor, nColor

   DO CASE
      CASE nNo = 1
         nColor := COLOR_SETUP.Text_BACKGROUND.Value
      CASE nNo = 2
         nColor := COLOR_SETUP.Text_FOREGRAUND.Value
   ENDCASE
   aColor := { GetRed( nColor ), GetGreen( nColor ), GetBlue( nColor ) }
   aColor := GetColor( aColor )

   nColor := RGB( aColor[ 1 ], aColor[ 2 ], aColor[ 3 ] )

   DO CASE
      CASE nNo = 1
         COLOR_SETUP.Text_BACKGROUND.Value := nColor
         BGfont := NumColor2RGB( nColor )
         COLOR_SETUP.Label_002.BackColor := FGfont
         COLOR_SETUP.Label_001.BackColor := BGfont

      CASE nNo = 2
         COLOR_SETUP.Text_FOREGRAUND.Value := nColor
         FGfont := NumColor2RGB( nColor )
         COLOR_SETUP.Label_002.BackColor := FGfont
         COLOR_SETUP.Label_001.BackColor := BGfont
   ENDCASE

RETURN

*+--------------------------------------------------------------------
*+
*+    Function NumColor2RGB()
*+
*+    Called from ( color.prg )   2 - static procedure color_replace()
*+                                   2 - static procedure colorpicker()
*+                ( forumhmg.prg )   2 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION NumColor2RGB( nColor )

LOCAL aRetVal

   DEFAULT nColor TO - 1

   IF nColor == - 1
      aRetVal := { NIL, NIL, NIL }
   ELSE
      aRetVal := { GetRed( nColor ), GetGreen( nColor ), GetBlue( nColor ) }
   ENDIF

RETURN aRetVal

*+--------------------------------------------------------------------
*+
*+    Function SysColor2Num()
*+
*+    Called from ( forumhmg.prg )   2 - static procedure createcolor()
*+
*+--------------------------------------------------------------------
*+
FUNCTION SysColor2Num( nColor )

RETURN GetSysColor( nColor )

*+ EOF: COLOR.PRG
